==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieWplataPozycjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class SwiadczenieWplataPozycjaKey extends GenericDPSObject {
    /**
     * SWIADCZENIE_WPLATA_POZYCJA.WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wplataId;

    /**
     * SWIADCZENIE_WPLATA_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieWplataId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_WPLATA_POZYCJA.WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWplataId() {
        return wplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * SWIADCZENIE_WPLATA_POZYCJA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @return SWIADCZENIE_WPLATA_POZYCJA.SWIADCZENIE_WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieWplataId() {
        return swiadczenieWplataId;
    }

    /**
     * SWIADCZENIE_WPLATA_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @param swiadczenieWplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieWplataId(Long swiadczenieWplataId) {
        this.swiadczenieWplataId = swiadczenieWplataId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieWplataPozycjaKey other = (SwiadczenieWplataPozycjaKey) that;
        return (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()))
            && (this.getSwiadczenieWplataId() == null ? other.getSwiadczenieWplataId() == null : this.getSwiadczenieWplataId().equals(other.getSwiadczenieWplataId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        result = prime * result + ((getSwiadczenieWplataId() == null) ? 0 : getSwiadczenieWplataId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", wplataId=").append(wplataId);
        sb.append(", swiadczenieWplataId=").append(swiadczenieWplataId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieWplataPozycjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class SwiadczenieWplataPozycjaKey extends GenericDPSObject {
    /**
     * SWIADCZENIE_WPLATA_POZYCJA.WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wplataId;

    /**
     * SWIADCZENIE_WPLATA_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieWplataId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_WPLATA_POZYCJA.WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWplataId() {
        return wplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * SWIADCZENIE_WPLATA_POZYCJA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @return SWIADCZENIE_WPLATA_POZYCJA.SWIADCZENIE_WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieWplataId() {
        return swiadczenieWplataId;
    }

    /**
     * SWIADCZENIE_WPLATA_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @param swiadczenieWplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieWplataId(Long swiadczenieWplataId) {
        this.swiadczenieWplataId = swiadczenieWplataId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieWplataPozycjaKey other = (SwiadczenieWplataPozycjaKey) that;
        return (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()))
            && (this.getSwiadczenieWplataId() == null ? other.getSwiadczenieWplataId() == null : this.getSwiadczenieWplataId().equals(other.getSwiadczenieWplataId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        result = prime * result + ((getSwiadczenieWplataId() == null) ? 0 : getSwiadczenieWplataId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", wplataId=").append(wplataId);
        sb.append(", swiadczenieWplataId=").append(swiadczenieWplataId);
        sb.append("]");
        return sb.toString();
    }
}
